package com.ruoyi.mall.service.impl;

import java.util.List;

import com.ruoyi.mall.domain.vo.GoodsProductVO;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallGoodsProductMapper;
import com.ruoyi.mall.domain.MallGoodsProduct;
import com.ruoyi.mall.service.IMallGoodsProductService;

/**
 * 商品 产品Service业务层处理
 *
 * @author chang
 * @date 2021-11-25
 */
@Service
public class MallGoodsProductServiceImpl implements IMallGoodsProductService
{
    @Autowired
    private MallGoodsProductMapper mallGoodsProductMapper;

    /**
     * 查询商品 产品
     *
     * @param id 商品 产品主键
     * @return 商品 产品
     */
    @Override
    public MallGoodsProduct selectMallGoodsProductById(Long id)
    {
        return mallGoodsProductMapper.selectMallGoodsProductById(id);
    }

    /**
     * 查询商品 产品列表
     *
     * @param mallGoodsProduct 商品 产品
     * @return 商品 产品
     */
    @Override
    public List<MallGoodsProduct> selectMallGoodsProductList(MallGoodsProduct mallGoodsProduct)
    {
        return mallGoodsProductMapper.selectMallGoodsProductList(mallGoodsProduct);
    }

    /**
     * 新增商品 产品
     *
     * @param mallGoodsProduct 商品 产品
     * @return 结果
     */
    @Override
    public int insertMallGoodsProduct(MallGoodsProduct mallGoodsProduct)
    {
        return mallGoodsProductMapper.insertMallGoodsProduct(mallGoodsProduct);
    }

    /**
     * 修改商品 产品
     *
     * @param mallGoodsProduct 商品 产品
     * @return 结果
     */
    @Override
    public int updateMallGoodsProduct(MallGoodsProduct mallGoodsProduct)
    {
        return mallGoodsProductMapper.updateMallGoodsProduct(mallGoodsProduct);
    }

    /**
     * 批量删除商品 产品
     *
     * @param ids 需要删除的商品 产品主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsProductByIds(Long[] ids)
    {
        return mallGoodsProductMapper.deleteMallGoodsProductByIds(ids);
    }

    /**
     * 删除商品 产品信息
     *
     * @param id 商品 产品主键
     * @return 结果
     */
    @Override
    public int deleteMallGoodsProductById(Long id)
    {
        return mallGoodsProductMapper.deleteMallGoodsProductById(id);
    }

    @Override
    public List<GoodsProductVO> selectMallGoodProByParams(MallGoodsProduct pro) {
        return mallGoodsProductMapper.selectMallGoodProByParams(pro);
    }

    @Override
    public void updateMallGoodsProductByParamsRefund(Long productId, Integer total) {
        mallGoodsProductMapper.updateMallGoodsProductByParamsRefund(productId,total);
    }

    @Override
    public void updateMallGoodsProductByParams(Long productId, Integer total) {
        mallGoodsProductMapper.updateMallGoodsProductByParams(productId,total);
    }

    /**
     * 设置一个默认规格
     *
     * @param goodsId 商品ID
     * @return 商品 产品集合
     */
    @Override
    public int setDefault(Long goodsId) {
        mallGoodsProductMapper.setNotDefault(goodsId);
        return mallGoodsProductMapper.setDefault(goodsId);
    }
}
